<?php
/*
Plugin Name: Adcell.de - Gutschein Widget
Plugin URI: http://www.adcell.de/
Description: Ein Sidebar-Widget für Adcell.de - stellt dynamisch einen (oder mehrere) Gutschein(e) von diversen Partnerprogrammen dar.
Version: 0.1.0.0
Author: Nils Wiegner
Author URI: https://www.xing.com/profile/Nils_Wiegner
License: GPLv2
*/

/*
This program is free software; you can redistribute it and/or modify 
it under the terms of the GNU General Public License as published by 
the Free Software Foundation; version 2 of the License.

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License 
along with this program; if not, write to the Free Software 
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
*/

add_action(
  'widgets_init', 
  create_function(
    '', 
    'return register_widget("AdcellCouponWidget");'
  )
);

class AdcellCouponWidget extends WP_Widget 
{
    function AdcellCouponWidget() 
    {
       parent::WP_Widget(
         false, 
         $name = 'Adcell Gutschein Widget',
         // Wtf? That's kind of an API break - why is $name not included in 
         // $widget_options? Oh well... 
         array(
          'description' => 'Das offizielle ADCELL.de Gutschein-Widget.'
         )
       );	
    }

    function widget($args, $instance) 
    {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);
        echo $before_widget;
        echo $before_title . $title . $after_title;
        
        $adcellUserID   = $instance['userID'];
        $adcellPassword = $instance['password'];
        
        if (empty($adcellUserID) || empty($adcellPassword)) {
          echo '<strong><font color="red">Fehler:</font></strong><br />Es wurde kein ADCELL-Benutzername bzw. Passwort eingetragen. Bitte im Widget korrigieren.';
          echo $after_widget;
          return;
        }
        
        $couponCount    = $instance['couponCount'];
        $showPictures   = $instance['showPictures'] == 1;
        $allowErotic    = $instance['allowErotic'] == 1;
        $divStyle       = $instance['divStyle'];
        
        require_once 'adcell.widget.class.php';
        $coupons = Adcell::GetCoupons($adcellUserID, $adcellPassword, $couponCount, $allowErotic);
        
        foreach ($coupons as $coupon) {
          echo "<div style=\"$divStyle\">";
          echo "<h3 style=\"color:#000;font-weight:bold;margin-top:5px;\">{$coupon['ShopName']}</h3>";
          if ($showPictures)
            echo "<a title=\"{$coupon['ShopName']} Gutscheincode\" href=\"{$coupon['AffiliateLink']}\" rel=\"nofollow\"><img style=\"border:1px solid;margin-top:10px;\" src=\"{$coupon['ShopLogo']}\"></a>";
          echo "<div style=\"margin:5px;text-align:left\">";
          echo "<p><strong>Beschreibung</strong>: {$coupon['CouponInfo']}</p>";
          echo "<p><strong>Gutscheincode</strong>: {$coupon['CouponCode']}</p>";
          echo "<p><strong>Gültig bis</strong>: {$coupon['Expires']}</p>";
          echo "</div>";
          echo "<p>&raquo; <a rel=\"nofollow\" href=\"{$coupon['AffiliateLink']}\"><strong>Hier einlösen</strong></a> &laquo;</p>";
          echo "</div>";
        }
        
        echo $after_widget;
    }

    function update($newInstance, $oldInstance) 
    {				
	     $instance = $oldInstance;
	     
	     foreach ($newInstance as $key => $value) {
	       $value = is_numeric($newInstance[$key]) || $key == 'divStyle' ? $newInstance[$key] : strip_tags($newInstance[$key]);
         $instance[$key] = $value;
       }

       return $instance;
    }


    function form($instance) 
    {			
        echo "<center><img src=\"https://www.adcell.de/images/ADCELL_120x60.jpg\"></center>";
        $title = esc_attr($instance['title']);
        $title = empty($title) ? 'Gutscheine' : $title;
        echo '<p><label for="' . $this->get_field_id('title') . '">';
        echo _e('Widget-Titel:');
        echo '<input class="widefat" id="' . $this->get_field_id('title') .'" name="' . $this->get_field_name('title') . '" type="text" value="' . $title . '" /><br />';
        echo '</label></p>';
        
        $userID = esc_attr($instance['userID']);
        echo '<p><label for="' . $this->get_field_id('userID') . '">';
        echo _e('Adcell User ID:');
        echo '<input class="widefat" id="' . $this->get_field_id('userID') .'" name="' . $this->get_field_name('userID') . '" type="text" value="' . $userID . '" /><br />';
        echo '</label></p>';
        
        $password = esc_attr($instance['password']);
        echo '<p><label for="' . $this->get_field_id('password') . '">';
        echo _e('<a target="_blank" href="https://www.adcell.de/user/aboutme/selectedTab/password">Adcell Schnittstellen-Passwort:</a>');
        echo '<input class="widefat" id="' . $this->get_field_id('password') .'" name="' . $this->get_field_name('password') . '" type="password" value="' . $password . '" /><br />';
        echo '</label></p>';

        $couponCount = (int) esc_attr($instance['couponCount']);
        $couponCount = empty($couponCount) ? 1 : $couponCount;
        echo '<p><label for="' . $this->get_field_id('couponCount') . '">';
        echo _e('Gutscheine anzeigen:');
        echo '<select id="' . $this->get_field_id('couponCount') . '" name="' . $this->get_field_name('couponCount') . '" class="widefat">';
        for ($i = 1; $i <= 15; $i++) {
          $selected = $i == $couponCount ? ' selected="selected"' : '';
          echo "<option value=\"$i\"{$selected}>$i</option>";
        }
        echo '</select>';
        echo '</label></p>';
        
        $showPictures = (int) esc_attr($instance['showPictures']);
        
        echo '<p><label for="' . $this->get_field_id('showPictures') . '">';
        echo _e('Shoplogos anzeigen:');
        echo '<select id="' . $this->get_field_id('showPictures') . '" name="' . $this->get_field_name('showPictures') . '" class="widefat"><br />';
        $selected = $showPictures == 1 ? ' selected="selected"' : '';
        echo "<option value=\"1\"$selected>Ja</option>";
        $selected = $showPictures == 0 ? ' selected="selected"' : '';
        echo "<option value=\"0\"$selected>Nein</option>";      
        echo '</select>';
        echo '</label></p>';
        
        $allowErotic = (int) esc_attr($instance['allowErotic']);
        
        echo '<p><label for="' . $this->get_field_id('allowErotic') . '">';
        echo _e('Erotik erlaubt:');
        echo '<select id="' . $this->get_field_id('allowErotic') . '" name="' . $this->get_field_name('allowErotic') . '" class="widefat"><br />';
        $selected = $allowErotic == 1 ? ' selected="selected"' : '';
        echo "<option value=\"1\"$selected>Ja</option>";
        $selected = $allowErotic == 0 ? ' selected="selected"' : '';
        echo "<option value=\"0\"$selected>Nein</option>";      
        echo '</select>';
        echo '</label></p>';
        
        $divStyle = esc_attr($instance['divStyle']);
        $divStyle = empty($divStyle) ? 'background:url(https://www.adcell.de/images/content-bg.gif) repeat-x #ffffff;border-top:1px solid #81AFD0;border-left:1px solid #81AFD0;border-right:1px solid #81AFD0;border-bottom:10px solid #81AFD0;font-family:arial;margin-top:5px;padding:10px;text-align:center;color:#000;' : $divStyle;
        echo '<p><label for="' . $this->get_field_id('divStyle') . '">';
        echo _e('Gutschein-Div Style:');
        echo '<input class="widefat" id="' . $this->get_field_id('divStyle') .'" name="' . $this->get_field_name('divStyle') . '" type="text" value="' . $divStyle . '" /><br />';
        echo '</label></p>';                                                  
    }
}
?>